@@ -49,6 +49,37 @@ enum SType { kSInt, kSReal };
 
 enum SOperator { kAdd, kSub, kMul, kDiv, kRem, kLsh, kARsh, kLRsh, kGT, kLT, kGE, kLE, kEQ, kNE, kAND, kOR, kXOR };
 
+#ifdef __cplusplus
+extern "C"
+{
+#endif
+    
+    /**
+     * Print the box.
+     *
+     * @param box - the box to be printed
+     * @param shared - whether the identical sub boxes are printed as identifiers
+     * @param max_size - the maximum number of characters to be printed (possibly needed for big expressions in non shared mode)
+     *
+     * @return the printed box as a string (to be deleted by the caller using freeCMemory)
+     */
+    LIBFAUST_API char* CprintBox(Box box, bool shared, int max_size);
+
+    /**
+     * Print the signal.
+     *
+     * @param sig - the signal to be printed
+     * @param shared - whether the identical sub signals are printed as identifiers
+     * @param max_size - the maximum number of characters to be printed (possibly needed for big expressions in non shared mode)
+     *
+     * @return the printed signal as a string (to be deleted by the caller using freeCMemory)
+     */
+    LIBFAUST_API char* CprintSignal(Signal sig, bool shared, int max_size);
+
+#ifdef __cplusplus
+}
+#endif
+
 #endif
 
 #ifndef LIBFAUSTSIGNAL_C_H
@@ -133,6 +164,16 @@ extern "C"
      */
     LIBFAUST_API Signal CsigDelay(Signal s, Signal del);
     
+    /**
+     * Create a one sample delayed signal.
+     *
+     * @param s - the signal to be delayed
+     *
+     * @return the delayed signal.
+     */
+    LIBFAUST_API Signal CsigDelay1(Signal s);
+
+    
     /**
      * Create a casted signal.
      *
@@ -533,7 +574,7 @@ extern "C"
     /**
      *  Simplify a signal to its normal form, where:
      *  - all possible optimisations, simplications, and compile time computations have been done
-     *  - the mathematical functions (primitives and binary functions), delay, select2, sounfile primitive...
+     *  - the mathematical functions (primitives and binary functions), delay, select2, soundfile primitive...
      *  are properly typed (arguments and result)
      *  - signal cast are properly done when needed
      *
@@ -546,7 +587,7 @@ extern "C"
     /**
      *  Simplify a null terminated array of signals to its normal form, where:
      *  - all possible optimisations, simplications, and compile time computations have been done
-     *  - the mathematical functions (primitives and binary functions), delay, select2, sounfile primitive...
+     *  - the mathematical functions (primitives and binary functions), delay, select2, soundfile primitive...
      *  are properly typed (arguments and result)
      *  - signal cast are properly done when needed
      *
@@ -555,6 +596,28 @@ extern "C"
      * @return the null terminated array of signals in normal form (to be deleted by the caller using freeCMemory).
      */
     LIBFAUST_API Signal* CsimplifyToNormalForm2(Signal* siglist);
+    
+    /**
+     * Create source code in a target language from a null terminated array of output signals.
+     *
+     * @param name_app - the name of the Faust program
+     * @param osigs - the null terminated array of output signals (that will internally be converted in normal form,
+     * see simplifyToNormalForm)
+     * @param lang - the target source code's language which can be one of "c",
+     * "cpp", "cmajor", "codebox", "csharp", "dlang", "fir", "interp", "java", "jax",
+     * "jsfx", "julia", "ocpp", "rust" or "wast"
+     * (depending of which of the corresponding backends are compiled in libfaust)
+     * @param argc - the number of parameters in argv array
+     * @param argv - the array of parameters
+     * @param error_msg - the error string to be filled
+     *
+     * @return a string of source code on success (to be deleted by the caller using freeCMemory) or a nullptr and setting error_msg on error.
+     */
+    LIBFAUST_API char* CcreateSourceFromSignals(const char* name_app, Signal* osigs,
+                                                const char* lang,
+                                                int argc, const char* argv[],
+                                                char* error_msg);
+
 
     /*
      [1] Constant numerical expression : see https://faustdoc.grame.fr/manual/syntax/#constant-numerical-expressions
