@@ -28,6 +28,7 @@
 #include <string>
 #include <vector>
 #include <ostream>
+#include <limits>
 
 #include "faust/export.h"
 
@@ -91,7 +92,7 @@ struct LIBFAUST_API dsp_factory_base {
 };
 
 /**
- *  Print the box.
+ * Print the box.
  *
  * @param box - the box to be printed
  * @param shared - whether the identical sub boxes are printed as identifiers
@@ -102,7 +103,7 @@ struct LIBFAUST_API dsp_factory_base {
 LIBFAUST_API std::string printBox(Box box, bool shared, int max_size);
 
 /**
- *  Print the signal.
+ * Print the signal.
  *
  * @param sig - the signal to be printed
  * @param shared - whether the identical sub signals are printed as identifiers
@@ -117,6 +118,28 @@ LIBFAUST_API std::string printSignal(Signal sig, bool shared, int max_size);
 #ifndef LIBFAUSTSIGNAL_H
 #define LIBFAUSTSIGNAL_H
 
+// To be used with getSigInterval/setSigInterval
+// see: https://stackoverflow.com/questions/27442885/syntax-error-with-stdnumeric-limitsmax
+struct Interval {
+    double fLo = std::numeric_limits<double>::lowest();    //< minimal value
+    double fHi = (std::numeric_limits<double>::max)();     //< maximal value
+    int    fLSB = -24;                                     //< lsb in bits
+    
+    // To be used to set a full interval
+    Interval(double lo, double hi, int lsb):fLo(lo), fHi(hi), fLSB(lsb)
+    {}
+    
+    // To be used to only set the LSB, with fLo and fHi taking default values
+    Interval(int lsb):fLSB(lsb)
+    {}
+};
+
+inline static std::ostream& operator<<(std::ostream& dst, const Interval& it)
+{
+    dst << "Interval [" << it.fLo << ", " << it.fHi << ", " << it.fLSB << "]";
+    return dst;
+}
+
 /**
  * Create global compilation context, has to be done first.
  */
@@ -127,6 +150,23 @@ extern "C" LIBFAUST_API void createLibContext();
  */
 extern "C" LIBFAUST_API void destroyLibContext();
 
+/**
+ * Get the signal interval.
+ * 
+ * @param s - the signal
+ * 
+ * @return the signal interval
+ */
+LIBFAUST_API Interval getSigInterval(Signal s);
+
+/**
+ * Set the signal interval.
+ * 
+ * @param s - the signal
+ * @param inter - the signal interval
+ */
+LIBFAUST_API void setSigInterval(Signal s, Interval& inter);
+
 /**
  * Check if a signal is nil.
  *
@@ -209,6 +249,15 @@ LIBFAUST_API Signal sigInput(int idx);
  */
 LIBFAUST_API Signal sigDelay(Signal s, Signal del);
 
+/**
+ * Create a one sample delayed signal.
+ *
+ * @param s - the signal to be delayed
+ *
+ * @return the delayed signal.
+ */
+LIBFAUST_API Signal sigDelay1(Signal s);
+
 /**
  * Create a casted signal.
  *
@@ -549,53 +598,6 @@ LIBFAUST_API Signal sigHBargraph(const std::string& label, Signal min, Signal ma
  */
 LIBFAUST_API Signal sigAttach(Signal s1, Signal s2);
 
-/**
- *  Simplify a signal to its normal form, where:
- *  - all possible optimisations, simplications, and compile time computations have been done
- *  - the mathematical functions (primitives and binary functions), delay, select2, sounfile primitive...
- *  are properly typed (arguments and result)
- *  - signal cast are properly done when needed
- *
- * @param sig - the signal to be processed
- *
- * @return the signal in normal form.
- */
-LIBFAUST_API Signal simplifyToNormalForm(Signal s);
-
-/**
- *  Simplify a signal vector to its normal form, where:
- *  - all possible optimisations, simplications, and compile time computations have been done
- *  - the mathematical functions (primitives and binary functions), delay, select2, sounfile primitive...
- *  are properly typed (arguments and result)
- *  - signal cast are properly done when needed
- *
- * @param siglist - the signal vector to be processed
- *
- * @return the signal vector in normal form.
- */
-LIBFAUST_API tvec simplifyToNormalForm2(tvec siglist);
-
-/**
- * Create source code in a target language from a vector of output signals.
- *
- * @param name_app - the name of the Faust program
- * @param osigs - the vector of output signals (that will internally be converted in normal form,
- * see simplifyToNormalForm)
- * @param lang - the target source code's language which can be one of "c",
- * "cpp", "csharp", "dlang", "fir", "java", "julia", "ocpp", "rust", "soul" or "wast"
- * (depending of which of the corresponding backends are compiled in libfaust)
- * @param argc - the number of parameters in argv array
- * @param argv - the array of parameters
- * @param error_msg - the error string to be filled
- *
- * @return a string of source code on success, setting error_msg on error.
- */
-LIBFAUST_API std::string createSourceFromSignals(const std::string& name_app, tvec osigs,
-                                                const std::string& lang,
-                                                int argc, const char* argv[],
-                                                std::string& error_msg);
-
-
 /**
  * Test each signal and fill additional signal specific parameters.
  *
@@ -652,6 +654,53 @@ LIBFAUST_API bool isSigSoundfileLength(Signal s, Signal& sf, Signal& part);
 LIBFAUST_API bool isSigSoundfileRate(Signal s, Signal& sf, Signal& part);
 LIBFAUST_API bool isSigSoundfileBuffer(Signal s, Signal& sf, Signal& chan, Signal& part, Signal& ridx);
 
+/**
+ *  Simplify a signal to its normal form, where:
+ *  - all possible optimisations, simplications, and compile time computations have been done
+ *  - the mathematical functions (primitives and binary functions), delay, select2, soundfile primitive...
+ *  are properly typed (arguments and result)
+ *  - signal cast are properly done when needed
+ *
+ * @param sig - the signal to be processed
+ *
+ * @return the signal in normal form.
+ */
+LIBFAUST_API Signal simplifyToNormalForm(Signal s);
+
+/**
+ *  Simplify a signal list to its normal form, where:
+ *  - all possible optimisations, simplications, and compile time computations have been done
+ *  - the mathematical functions (primitives and binary functions), delay, select2, soundfile primitive...
+ *  are properly typed (arguments and result)
+ *  - signal cast are properly done when needed
+ *
+ * @param siglist - the signal list to be processed
+ *
+ * @return the signal vector in normal form.
+ */
+LIBFAUST_API tvec simplifyToNormalForm2(tvec siglist);
+
+/**
+ * Create source code in a target language from a vector of output signals.
+ *
+ * @param name_app - the name of the Faust program
+ * @param osigs - the vector of output signals (that will internally be converted in normal form,
+ * see simplifyToNormalForm)
+ * @param lang - the target source code's language which can be one of "c",
+ * "cpp", "cmajor", "codebox", "csharp", "dlang", "fir", "interp", "java", "jax",
+ * "jsfx", "julia", "ocpp", "rust" or "wast"
+ * (depending of which of the corresponding backends are compiled in libfaust)
+ * @param argc - the number of parameters in argv array
+ * @param argv - the array of parameters
+ * @param error_msg - the error string to be filled
+ *
+ * @return a string of source code on success, setting error_msg on error.
+ */
+LIBFAUST_API std::string createSourceFromSignals(const std::string& name_app, tvec osigs,
+                                                 const std::string& lang,
+                                                 int argc, const char* argv[],
+                                                 std::string& error_msg);
+
 /*
  [1] Constant numerical expression : see https://faustdoc.grame.fr/manual/syntax/#constant-numerical-expressions
  [2] Label definition : https://faustdoc.grame.fr/manual/syntax/#variable-parts-of-a-label
