@@ -1592,8 +1592,10 @@ public:
      * \brief   Constructor.
      * \details Initalize the juce::TabbedComponent tabs to be at top, and the uiTabBox size at 0
      */
-    uiTabBox():uiBase(),juce::TabbedComponent(juce::TabbedButtonBar::TabsAtTop)
-    {}
+    uiTabBox(juce::String label):uiBase(),juce::TabbedComponent(juce::TabbedButtonBar::TabsAtTop)
+    {
+        setName(label);
+    }
     
     /**
      * Initialize all his child ratios (1 uiBox per tabs), the LookAndFeel
@@ -1808,7 +1810,7 @@ class uiBox : public uiBase, public juce::Component
         void paint(juce::Graphics& g) override
         {
             // Fill the box background in gray shades
-            g.setColour(juce::Colours::black.withAlpha(0.05f));
+            g.setColour(juce::Colours::black.withAlpha(0.5f)); // 0.05, used until 2023-08-5, is not readable on the Mac
             g.fillRect(getLocalBounds());
 
             // Display the name if it's needed
@@ -1942,7 +1944,7 @@ class JuceGUI : public GUI, public MetaDataUI, public juce::Component
         /** Initialize the uiTabBox component to be visible. */
         virtual void openTabBox(const char* label) override
         {
-            openBox(new uiTabBox());
+            openBox(new uiTabBox(juce::String(label)));
         }
         
         /** Add a new vertical box to the user interface. */
