@@ -29,6 +29,7 @@
 #include <vector>
 #include <string>
 #include <iostream>
+#include <memory>
 
 #include "faust/gui/SimpleParser.h"
 #include "faust/gui/DecoratorUI.h"
@@ -58,7 +59,7 @@ static LibsndfileReader gReader;
 #endif
 
 // To be used by DSP code if no SoundUI is used
-static std::vector<std::string> path_name_list;
+static std::vector<std::string> gPathNameList;
 static Soundfile* defaultsound = nullptr;
 
 class SoundUI : public SoundUIInterface
@@ -66,9 +67,12 @@ class SoundUI : public SoundUIInterface
 		
     protected:
     
-        std::vector<std::string> fSoundfileDir;             // The soundfile directories
-        std::map<std::string, Soundfile*> fSoundfileMap;    // Map to share loaded soundfiles
-        SoundfileReader* fSoundReader;
+        // The soundfile directories
+        std::vector<std::string> fSoundfileDir;
+        // Map to share loaded soundfiles
+        std::map<std::string, std::shared_ptr<Soundfile>> fSoundfileMap;
+        // The soundfile reader
+        std::shared_ptr<SoundfileReader> fSoundReader;
         bool fIsDouble;
 
      public:
@@ -86,10 +90,13 @@ class SoundUI : public SoundUIInterface
         SoundUI(const std::string& sound_directory = "", int sample_rate = -1, SoundfileReader* reader = nullptr, bool is_double = false)
         {
             fSoundfileDir.push_back(sound_directory);
-            fSoundReader = (reader) ? reader : &gReader;
+            fSoundReader = (reader)
+                ? std::shared_ptr<SoundfileReader>(reader)
+                // the static gReader should not be deleted, so use an empty destructor
+                : std::shared_ptr<SoundfileReader>(std::shared_ptr<SoundfileReader>{}, &gReader);
             fSoundReader->setSampleRate(sample_rate);
             fIsDouble = is_double;
-            if (!defaultsound) defaultsound = gReader.createSoundfile(path_name_list, MAX_CHAN, is_double);
+            if (!defaultsound) defaultsound = gReader.createSoundfile(gPathNameList, MAX_CHAN, is_double);
         }
     
         /**
@@ -105,19 +112,17 @@ class SoundUI : public SoundUIInterface
         SoundUI(const std::vector<std::string>& sound_directories, int sample_rate = -1, SoundfileReader* reader = nullptr, bool is_double = false)
         :fSoundfileDir(sound_directories)
         {
-            fSoundReader = (reader) ? reader : &gReader;
+            fSoundReader = (reader)
+                ? std::shared_ptr<SoundfileReader>(reader)
+                // the static gReader should not be deleted, so use an empty destructor
+                : std::shared_ptr<SoundfileReader>(std::shared_ptr<SoundfileReader>{}, &gReader);
             fSoundReader->setSampleRate(sample_rate);
             fIsDouble = is_double;
-            if (!defaultsound) defaultsound = gReader.createSoundfile(path_name_list, MAX_CHAN, is_double);
+            if (!defaultsound) defaultsound = gReader.createSoundfile(gPathNameList, MAX_CHAN, is_double);
         }
     
         virtual ~SoundUI()
-        {   
-            // Delete all soundfiles
-            for (const auto& it : fSoundfileMap) {
-                delete it.second;
-            }
-        }
+        {}
 
         // -- soundfiles
         virtual void addSoundfile(const char* label, const char* url, Soundfile** sf_zone)
@@ -137,7 +142,7 @@ class SoundUI : public SoundUIInterface
                 // Read them and create the Soundfile
                 Soundfile* sound_file = fSoundReader->createSoundfile(path_name_list, MAX_CHAN, fIsDouble);
                 if (sound_file) {
-                    fSoundfileMap[saved_url_real] = sound_file;
+                    fSoundfileMap[saved_url_real] = std::shared_ptr<Soundfile>(sound_file);
                 } else {
                     // If failure, use 'defaultsound'
                     std::cerr << "addSoundfile : soundfile for " << saved_url << " cannot be created !" << std::endl;
@@ -146,8 +151,8 @@ class SoundUI : public SoundUIInterface
                 }
             }
             
-            // Get the soundfile
-            *sf_zone = fSoundfileMap[saved_url_real];
+            // Get the soundfile pointer
+            *sf_zone = fSoundfileMap[saved_url_real].get();
         }
     
         /**
